==> cds-integration-cloud-sdk-1.34.0-sources.jar: com/sap/cds/integration/cloudsdk/destination/HttpClientProvider.java <==
package com.sap.cds.integration.cloudsdk.destination;

import java.util.function.Supplier;

import org.apache.http.client.HttpClient;

import com.sap.cds.services.environment.CdsProperties.ConnectionPool;
import com.sap.cds.services.request.RequestContext;
import com.sap.cds.services.runtime.CdsRuntime;
import com.sap.cds.services.utils.TenantAwareCache;
import com.sap.cloud.sdk.cloudplatform.connectivity.DefaultHttpClientFactory;
import com.sap.cloud.sdk.cloudplatform.connectivity.HttpDestination;

public class HttpClientProvider implements Supplier<HttpClient> {

	private final TenantAwareCache<HttpClient, Boolean> clientCache;

	public HttpClientProvider(Supplier<HttpDestination> destinationSupplier, ConnectionPool config, CdsRuntime runtime) {
		DefaultHttpClientFactory.DefaultHttpClientFactoryBuilder builder = DefaultHttpClientFactory.builder();
		builder.timeoutMilliseconds((int)config.getTimeout().toMillis());
		builder.maxConnectionsPerRoute(config.getMaxConnectionsPerRoute());
		builder.maxConnectionsTotal(config.getMaxConnections());
		DefaultHttpClientFactory factory = builder.build();

		Supplier<String> tenantSupplier;
		if (config.getCombinePools().isEnabled()) {
			tenantSupplier = () -> "global-pool";
		} else {
			tenantSupplier = () -> RequestContext.isActive() ? RequestContext.getCurrent(runtime).getUserInfo().getTenant() : runtime.getProvidedUserInfo().getTenant();
		}
		this.clientCache = TenantAwareCache.create(tenantSupplier, () -> factory.createHttpClient(destinationSupplier.get()), () -> true);
	}

	@Override
	public HttpClient get() {
		return clientCache.findOrCreate();
	}

}

==> cds-integration-cloud-sdk-2.4.1-sources.jar: com/sap/cds/integration/cloudsdk/destination/HttpClientProvider.java <==
package com.sap.cds.integration.cloudsdk.destination;

import java.util.function.Supplier;

import org.apache.http.client.HttpClient;

import com.sap.cds.services.environment.CdsProperties.ConnectionPool;
import com.sap.cds.services.request.RequestContext;
import com.sap.cds.services.runtime.CdsRuntime;
import com.sap.cds.services.utils.TenantAwareCache;
import com.sap.cloud.sdk.cloudplatform.connectivity.DefaultHttpClientFactory;
import com.sap.cloud.sdk.cloudplatform.connectivity.HttpDestination;

public class HttpClientProvider implements Supplier<HttpClient> {

	private final TenantAwareCache<HttpClient, Boolean> clientCache;

	public HttpClientProvider(HttpDestination destination, ConnectionPool config, CdsRuntime runtime) {
		DefaultHttpClientFactory.DefaultHttpClientFactoryBuilder builder = DefaultHttpClientFactory.builder();
		builder.timeoutMilliseconds((int)config.getTimeout().toMillis());
		builder.maxConnectionsPerRoute(config.getMaxConnectionsPerRoute());
		builder.maxConnectionsTotal(config.getMaxConnections());
		DefaultHttpClientFactory factory = builder.build();

		Supplier<String> tenantSupplier;
		if (config.getCombinePools().isEnabled()) {
			tenantSupplier = () -> "global-pool";
		} else {
			tenantSupplier = () -> RequestContext.isActive() ? RequestContext.getCurrent(runtime).getUserInfo().getTenant() : runtime.getProvidedUserInfo().getTenant();
		}
		this.clientCache = TenantAwareCache.create(tenantSupplier, () -> factory.createHttpClient(destination), () -> true);
	}

	@Override
	public HttpClient get() {
		return clientCache.findOrCreate();
	}

}
